@@ -1,6 +1,7 @@
 # Todo test mp
 from test.example_runner import run_docstring_example
 
+
 def test_func_fullname():
     """
     >>> def test_func_fullname_example1():
@@ -10,4 +11,4 @@ def test_func_fullname():
     >>> def test_func_fullname_example3():
     ...     pass
     """
-    allure_report = run_docstring_example()
\ No newline at end of file
+    run_docstring_example()
